@@ -3,7 +3,7 @@ from random import randrange
 from pydicom.uid import PYDICOM_IMPLEMENTATION_UID 
 from dataclasses import dataclass
 
-COLOR_PALETTE= [
+COLOR_PALETTE = [
     [255, 0, 255],
     [0, 235, 235],
     [255, 255, 0],
@@ -27,6 +27,9 @@ COLOR_PALETTE= [
     [255, 225, 0]
 ]
 
+ROI_GENERATION_ALGORITHMS = ['AUTOMATIC',
+                             'SEMIAUTOMATIC',
+                             'MANUAL']
 
 class SOPClassUID:
     RTSTRUCT_IMPLEMENTATION_CLASS = PYDICOM_IMPLEMENTATION_UID  # TODO find out if this is ok
@@ -45,10 +48,12 @@ class ROIData:
     description: str = ''
     use_pin_hole: bool = False
     approximate_contours: bool = True
+    roi_generation_algorithm: Union[str, int] = 0
 
     def __post_init__(self):
         self.validate_color()
         self.add_default_values()
+        self.validate_roi_generation_algoirthm()
 
     def add_default_values(self):
         if self.color is None:
@@ -86,3 +91,24 @@ class ROIData:
                 self.color = [int(self.color[i:i+2], 16) for i in (0, 2, 4)]
             except Exception as e:
                 raise ValueError(f'{self.color} is an invalid color for an ROI')
+
+    def validate_roi_generation_algoirthm(self):
+
+        if isinstance(self.roi_generation_algorithm, int):
+            # for ints we use the predefined values in ROI_GENERATION_ALGORITHMS
+            if self.roi_generation_algorithm > 2 or self.roi_generation_algorithm < 0:
+                raise ValueError('roi_generation_algorithm must be either an int (0=\'AUTOMATIC\', 1=\'SEMIAUTOMATIC\', 2=\'MANUAL\') '
+                                 'or a str (not recomended).')
+            else:
+                self.roi_generation_algorithm = ROI_GENERATION_ALGORITHMS[self.roi_generation_algorithm]
+    
+        elif isinstance(self.roi_generation_algorithm, str):
+            # users can pick a str if they want to use a value other than the three default values
+            if self.roi_generation_algorithm not in ROI_GENERATION_ALGORITHMS:
+                print('Got self.roi_generation_algorithm {}. Some viewers might complain about this option. '
+                      'Better options might be 0=\'AUTOMATIC\', 1=\'SEMIAUTOMATIC\', or 2=\'MANUAL\'.'.format(self.roi_generation_algorithm))
+        
+        else:
+            raise TypeError('Expected int (0=\'AUTOMATIC\', 1=\'SEMIAUTOMATIC\', 2=\'MANUAL\') '
+                            'or a str (not recomended) for self.roi_generation_algorithm. Got {}.'.format(type(self.roi_generation_algorithm)))
+
